@@ -44,8 +44,11 @@ See the README file for an example usage of this module.
 """
 
 
-__version__ = "$Id: cloghandler.py 5490 2008-05-22 19:03:46Z lowell $"
+__version__ = "$Id: cloghandler.py 5500 2008-05-29 21:10:07Z lowell $"
 __author__ = "Lowell Alleman"
+__all__ = [
+    "ConcurrentRotatingFileHandler",
+]
 
 
 import os
@@ -110,9 +113,9 @@ class ConcurrentRotatingFileHandler(BaseRotatingHandler):
 
         This log handler assumes that all concurrent processes logging to a
         single file will are using only this class, and that the exact same
-        paramerers are provided to each instance of this class.  If, for
+        parameters are provided to each instance of this class.  If, for
         example, two different processes are using this class, but with
-        different values for 'maxBytes' or 'backupCount', then odd behaviour is
+        different values for 'maxBytes' or 'backupCount', then odd behavior is
         expected. The same is true if this class is used by one application, but
         the RotatingFileHandler is used by another.
 
@@ -129,9 +132,13 @@ class ConcurrentRotatingFileHandler(BaseRotatingHandler):
         # files using relative paths. But since that's not a "normal" thing to
         # do, and having an app call os.chdir() is a much more likely scenario
         # that should be supported. For the moment, we are just going to warn
-        # the user if they provide a relative path.
+        # the user if they provide a relative path and do some other voodoo
+        # logic that you'll just have to review for yourself.
+        
+        # if the given filename contains no path, we make an absolute path
         if not os.path.isabs(filename):
-            if FORCE_ABSOLUTE_PATH:
+            if FORCE_ABSOLUTE_PATH or \
+               not os.path.split(filename)[0]:
                 filename = os.path.abspath(filename)
             elif not supress_abs_warn:
                 from warnings import warn
@@ -284,3 +291,9 @@ class ConcurrentRotatingFileHandler(BaseRotatingHandler):
             else:
                 self._degrade(False, "Rotation done or not needed at this time")
         return False
+
+
+# Publish this class to the "logging.handlers" module so that it can be use 
+# from a logging config file via logging.config.fileConfig().
+import logging.handlers
+logging.handlers.ConcurrentRotatingFileHandler = ConcurrentRotatingFileHandler
